from .Lissener import lissen,stop_listen
from .speaker import speak
from .tempfile_manager import clean_tempfiles
from . import Recognizer
from . import Recorder
from . import speaker
from . import Lissener



from . import Recorder
from . import Recognizer
from . import tempfile_manager
names = [
    "wiseman"
]

__lissening = True

def lissen(function, recordtime=3,recorderfunction=Recorder.record,recognizefunction=Recognizer.recognize):
    global __lissening
    __lissening = True
    while __lissening:
        recordedfile = recorderfunction(recordtime)
        text = recognizefunction(recordedfile).lower()
        for name in names:
            replacedtext = text.replace(name, '')
            if name in text:
                function(name, replacedtext)
    
def stop_listen():
    global __lissening
    __lissening = False
    tempfile_manager.clean_tempfiles()


#tempfile_manager.py
import random
import string
import os
import glob
import time
def tempfilename():
    length = 22
    characters = string.ascii_letters + string.digits
    random_string = ''.join(random.choice(characters) for _ in range(length))
    return random_string

def clean_tempfiles():
    for file in glob.glob(os.path.join('temp', '*')):
        os.remove(file)
        print(file)